pub struct HookCommand {
pub type: String,
pub command: String,
pub timeout: u32,
}Expand description
A single hook command to execute as a subprocess.
Fields
type: StringCommand type — currently always “command”.
command: StringThe shell command to execute.
timeout: u32Timeout in seconds (clamped to 1..=600).
Implementations
Sourceimpl HookCommand
impl HookCommand
Sourcepub fn with_timeout(command: impl Into<String>, timeout: u32) -> Self
pub fn with_timeout(command: impl Into<String>, timeout: u32) -> Self
Create a new hook command with a custom timeout.
Sourcepub fn effective_timeout(&self) -> u32
pub fn effective_timeout(&self) -> u32
The effective timeout, clamped to the valid range.