pub struct HookMatcher {
pub matcher: Option<String>,
pub hooks: Vec<HookCommand>,
/* private fields */
}Expand description
A matcher that filters when hooks fire, with associated commands.
If matcher is None, the hooks fire for every occurrence of the event.
If matcher is Some(pattern), it is compiled as a regex and tested
against the match value (e.g., tool name).
Fields
matcher: Option<String>Optional regex pattern to filter events (e.g., tool name pattern).
hooks: Vec<HookCommand>Commands to execute when the matcher matches.
Implementations
Sourceimpl HookMatcher
impl HookMatcher
Sourcepub fn catch_all(hooks: Vec<HookCommand>) -> Self
pub fn catch_all(hooks: Vec<HookCommand>) -> Self
Create a matcher that matches everything.
Sourcepub fn with_pattern(pattern: impl Into<String>, hooks: Vec<HookCommand>) -> Self
pub fn with_pattern(pattern: impl Into<String>, hooks: Vec<HookCommand>) -> Self
Create a matcher with a regex pattern.